Name:           seeks
Version:        0.4.2
Release:        0.1.20130112git42b5f97%{?dist}
Summary:        An open decentralized platform for collaborative search

Group:          Applications/Internet
# The entire source code is AGPLv3 except :
# - the main seeks binary which is AGPLv3, GPLv2+ and LGPLv2 with exception
# - yui/ which is BSD
# See Licenses for details
License:        AGPLv3 and GPLv2+ and LGPLv2 with exceptions and BSD
URL:            http://www.seeks-project.info
# git clone git://seeks.git.sourceforge.net/gitroot/seeks/seeks
# cd seeks
# git checkout 42b5f97
# cd ..
# tar czf seeks-0.4.2-1.tar.gz seeks
Source0:        %{name}-%{version}.tar.gz
# Systemd file
Source1:        %{name}.service
# Logrotate conf
Source2:        %{name}.logrotate
# Change configuration
Patch0:         %{name}-datalogfiles.patch
# Fix compilations issues with opencv. Works for fedora >= 16 only
Patch1:         %{name}-opencv.patch
# Remove hash implementation, replacing it by use of mhash
Patch2:         %{name}-rmd160.patch

BuildRequires: automake libtool docbook2X libcurl-devel pcre-devel
BuildRequires: libxml2-devel libevent-devel tokyocabinet-devel
BuildRequires: protobuf-devel libicu-devel systemd-units opencv-devel
BuildRequires: gtest-devel libxslt-devel
BuildRequires: jsoncpp-devel mhash-devel
%if 0%{?fedora} >= 16
BuildRequires: opencv-devel
%endif
Requires(pre): shadow-utils
Requires(post): systemd-units systemd-sysv
Requires(preun): systemd-units
Requires(postun): systemd-units

%description
Seeks is a p2p pattern matching overlay network on top of existing search
engines. It provides collaborative websearch capabilities by automatically
regrouping users based on the similarity of their queries, and letting them
reorganize and evaluate the search results together. Seeks implements a
websearch proxy and a distributed hashtable for this purpose. 

%prep
%setup -q -n %{name}
%patch0 -p1 -b .datalogfiles
%if 0%{?fedora} >= 16
%patch1 -p1 -b .orig
%endif
# %patch2 -p1


%build
%global common_flags --disable-static --enable-httpserv-plugin --enable-xslserializer-plugin
%if 0%{?fedora} >= 16
./autogen.sh
%configure %common_flags
%else
%configure %common_flags --disable-opencv
%endif
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
make %{?_smp_mflags}

%install
# Install seeks
make install DESTDIR=$RPM_BUILD_ROOT
find $RPM_BUILD_ROOT%{_libdir} -name \*.la -delete
rm -rf $RPM_BUILD_ROOT%{_libdir}/%{name}/cli
rm $RPM_BUILD_ROOT%{_libdir}/*.so

# Install systemd file
mkdir -p $RPM_BUILD_ROOT%{_unitdir}
cp %{SOURCE1} $RPM_BUILD_ROOT%{_unitdir}/%{name}.service

# Install logrotate conf
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d
cp %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/%{name} 

mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/log/%{name}
mkdir -p $RPM_BUILD_ROOT%{_sharedstatedir}/%{name}

%pre
getent group seeks > /dev/null || groupadd -r seeks
getent passwd seeks > /dev/null \
    || useradd -r -g seeks -d /usr/share/seeks -s /sbin/nologin\
    -c "This account is used to run the seeks daemon" seeks
exit 0

%post 
/sbin/ldconfig
if [ $1 -eq "1" ]; then
    # Initial installation
    /bin/systemctl daemon-reload > /dev/null 2>&1 || :
fi

%preun 
if [ $1 -eq "0" ]; then
    # Package removal, not upgrade
    /bin/systemctl --no-reload disable %{name}.service > /dev/null 2>&1 || :
    /bin/systemctl stop %{name}.service > /dev/null 2>&1 || :
fi

%postun 
/sbin/ldconfig
if [ $1 -gt "0" ]; then
    # Package upgrade, not uninstall
    /bin/systemctl try-restart %{name}.service > /dev/null 2>&1 || :
fi

%triggerun -- %{name} < 0.3.4
/usr/bin/systemd-sysv-convert --save %{name} > /dev/null 2>&1 || :
/sbin/chkconfig --del %{name} > /dev/null 2>&1 || :
/bin/systemctl try-restart %{name}.service > /dev/null 2>&1 || :

%files
%defattr(-,%{name},%{name},-)
%{_sharedstatedir}/%{name}
%{_localstatedir}/log/%{name}

%defattr(-,root,root,-)
%{_bindir}/*
%{_libdir}/%{name}
%{_libdir}/*.so*
%{_datadir}/%{name}
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/%{name}
%{_mandir}/man1/*
%doc AUTHORS COPYING ChangeLog README Licenses *.txt

%defattr(0644,root,root,-)
%{_unitdir}/%{name}.service

%changelog
* Sat Jan 12 2013 Sebastien Willmann <sebastien.willmann@gmail.com> - 0.4.2-0.1.20130112git42b5f97
- Update to 0.4.2 (experimental)

* Sat Jul 21 2012 Sébastien Willmann <sebastien.willmann@gmail.com> - 0.4.1-1
- Update to version 0.4.1

* Mon Nov 21 2011 Sébastien Willmann <sebastien.willmann@gmail.com> - 0.4.0-1
- Update to version 0.4.0

* Sun Nov 13 2011 Sébastien Willmann <sebastien.willmann@gmail.com> - 0.4.0-0.7.RC2
- Removed rpath

* Sat Nov 12 2011 Sébastien Willmann <sebastien.willmann@gmail.com> - 0.4.0-0.6.RC2
- Activated the xsl serializer plugin

* Sun Nov 06 2011 Sébastien Willmann <sebastien.willmann@gmail.com> - 0.4.0-0.5.RC2
- Update to 0.4 RC2. docbook and compilation issues are fixed upstream. 
- Fixed a previous changelog entry.
- Removed BuildRoot.

* Wed Oct 26 2011 Sébastien Willmann <sebastien.willmann@gmail.com> - 0.4.0-0.4.RC1
- Fixed a compilation issue on i386

* Tue Oct 25 2011 Sébastien Willmann <sebastien.willmann@gmail.com> - 0.4.0-0.3.RC1
- Added licenses files, removed a static library, removed clean section

* Mon Oct 24 2011 Sébastien Willmann <sebastien.willmann@gmail.com> - 0.4.0-0.2.RC1
- Fixed seeks.service defattr

* Sun Oct 23 2011 Sébastien Willmann <sebastien.willmann@gmail.com> - 0.4.0-0.1.RC1
- Update to version 0.4.0-RC1

* Tue Oct 04 2011 Sébastien Willmann <sebastien.willmann@gmail.com> - 0.3.5a-3
- Removed devel package, which is useless

* Sun Oct 02 2011 Sébastien Willmann <sebastien.willmann@gmail.com> - 0.3.5a-2
- Added license breakdown informations

* Sat Oct 01 2011 Sébastien Willmann <sebastien.willmann@gmail.com> - 0.3.5a-1
- Update to version 0.3.5a

* Fri Aug 05 2011 Sebastien Willmann <sebastien.willmann@gmail.com> - 0.3.4-1
- Update to version 0.3.4, moved to systemd, changed description

* Sun May 15 2011 Sebastien Willmann <sebastien.willmann@gmail.com> - 0.3.3-1
- Upgrade to version 0.3.3

* Sat Feb 19 2011 Sebastien Willmann <sebastien.willmann@gmail.com> - 0.3.2-2
- Fixed files owners, added devel package

* Sun Feb 13 2011 Sebastien Willmann <sebastien.willmann@gmail.com> - 0.3.2-1
- Update to version 0.3.2

* Sat Feb 05 2011 Sebastien Willmann <sebastien.willmann@gmail.com> - 0.3.1-3
- Added logrotate configuration

* Sat Dec 18 2010 Sebastien Willmann <sebastien.willmann@gmail.com> - 0.3.1-2
- Added seeks user

* Sat Dec 18 2010 Sebastien Willmann <sebastien.willmann@gmail.com> - 0.3.1-1
- Updated to version 0.3.1 and added init script

* Sat Nov 20 2010 Sebastien Willmann <sebastien.willmann@gmail.com> - 0.3.0-3
- Fixed configuration

* Thu Nov 18 2010 Sebastien Willmann <sebastien.willmann@gmail.com> - 0.3.0-2
- Patched configuration file

* Fri Oct 15 2010 Sebastien Willmann <sebastien.willmann@gmail.com> - 0.3.0-1
- Update to version 0.3. Added http server plugin

* Wed Oct 06 2010 Sebastien Willmann <sebastien.willmann@gmail.com> - 0.2.5b-1
- Initial version of the package

